==> citrus-spring-4.0.2-sources.jar: org/citrusframework/model/testcase/core/TestcaseModel.java <==
//
// Diese Datei wurde mit der Eclipse Implementation of JAXB, v4.0.3 generiert 
// Siehe https://eclipse-ee4j.github.io/jaxb-ri 
// Änderungen an dieser Datei gehen bei einer Neukompilierung des Quellschemas verloren. 
//


package org.citrusframework.model.testcase.core;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlRootElement;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <p>Java-Klasse für anonymous complex type.
 * 
 * <p>Das folgende Schemafragment gibt den erwarteten Content an, der in dieser Klasse enthalten ist.
 * 
 * <pre>{@code
 * <complexType>
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <sequence>
 *         <element name="meta-info" type="{http://www.citrusframework.org/schema/testcase}MetaInfoType" minOccurs="0"/>
 *         <element ref="{http://www.citrusframework.org/schema/testcase}description" minOccurs="0"/>
 *         <element ref="{http://www.citrusframework.org/schema/testcase}variables" minOccurs="0"/>
 *         <element name="actions" type="{http://www.citrusframework.org/schema/testcase}TestActionsType"/>
 *         <element name="finally" type="{http://www.citrusframework.org/schema/testcase}TestActionsType" minOccurs="0"/>
 *       </sequence>
 *       <attribute name="name" use="required" type="{http://www.w3.org/2001/XMLSchema}string" />
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "metaInfo",
    "description",
    "variables",
    "actions",
    "_finally"
})
@XmlRootElement(name = "testcase")
public class TestcaseModel {

    @XmlElement(name = "meta-info")
    protected MetaInfoType metaInfo;
    protected String description;
    protected VariablesModel variables;
    @XmlElement(required = true)
    protected TestActionsType actions;
    @XmlElement(name = "finally")
    protected TestActionsType _finally;
    @XmlAttribute(name = "name", required = true)
    protected String name;

    /**
     * Ruft den Wert der metaInfo-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link MetaInfoType }
     *     
     */
    public MetaInfoType getMetaInfo() {
        return metaInfo;
    }

    /**
     * Legt den Wert der metaInfo-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link MetaInfoType }
     *     
     */
    public void setMetaInfo(MetaInfoType value) {
        this.metaInfo = value;
    }

    /**
     * Ruft den Wert der description-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDescription() {
        return description;
    }

    /**
     * Legt den Wert der description-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDescription(String value) {
        this.description = value;
    }

    /**
     * Ruft den Wert der variables-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link VariablesModel }
     *     
     */
    public VariablesModel getVariables() {
        return variables;
    }

    /**
     * Legt den Wert der variables-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link VariablesModel }
     *     
     */
    public void setVariables(VariablesModel value) {
        this.variables = value;
    }

    /**
     * Ruft den Wert der actions-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link TestActionsType }
     *     
     */
    public TestActionsType getActions() {
        return actions;
    }

    /**
     * Legt den Wert der actions-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link TestActionsType }
     *     
     */
    public void setActions(TestActionsType value) {
        this.actions = value;
    }

    /**
     * Ruft den Wert der finally-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link TestActionsType }
     *     
     */
    public TestActionsType getFinally() {
        return _finally;
    }

    /**
     * Legt den Wert der finally-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link TestActionsType }
     *     
     */
    public void setFinally(TestActionsType value) {
        this._finally = value;
    }

    /**
     * Ruft den Wert der name-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getName() {
        return name;
    }

    /**
     * Legt den Wert der name-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setName(String value) {
        this.name = value;
    }

}

==> citrus-spring-4.1.1-sources.jar: org/citrusframework/model/testcase/core/TestcaseModel.java <==
//
// Diese Datei wurde mit der Eclipse Implementation of JAXB, v4.0.4 generiert 
// Siehe https://eclipse-ee4j.github.io/jaxb-ri 
// Änderungen an dieser Datei gehen bei einer Neukompilierung des Quellschemas verloren. 
//


package org.citrusframework.model.testcase.core;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlRootElement;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <p>Java-Klasse für anonymous complex type.</p>
 * 
 * <p>Das folgende Schemafragment gibt den erwarteten Content an, der in dieser Klasse enthalten ist.</p>
 * 
 * <pre>{@code
 * <complexType>
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <sequence>
 *         <element name="meta-info" type="{http://www.citrusframework.org/schema/testcase}MetaInfoType" minOccurs="0"/>
 *         <element ref="{http://www.citrusframework.org/schema/testcase}description" minOccurs="0"/>
 *         <element ref="{http://www.citrusframework.org/schema/testcase}variables" minOccurs="0"/>
 *         <element name="actions" type="{http://www.citrusframework.org/schema/testcase}TestActionsType"/>
 *         <element name="finally" type="{http://www.citrusframework.org/schema/testcase}TestActionsType" minOccurs="0"/>
 *       </sequence>
 *       <attribute name="name" use="required" type="{http://www.w3.org/2001/XMLSchema}string" />
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "metaInfo",
    "description",
    "variables",
    "actions",
    "_finally"
})
@XmlRootElement(name = "testcase")
public class TestcaseModel {

    @XmlElement(name = "meta-info")
    protected MetaInfoType metaInfo;
    protected String description;
    protected VariablesModel variables;
    @XmlElement(required = true)
    protected TestActionsType actions;
    @XmlElement(name = "finally")
    protected TestActionsType _finally;
    @XmlAttribute(name = "name", required = true)
    protected String name;

    /**
     * Ruft den Wert der metaInfo-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link MetaInfoType }
     *     
     */
    public MetaInfoType getMetaInfo() {
        return metaInfo;
    }

    /**
     * Legt den Wert der metaInfo-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link MetaInfoType }
     *     
     */
    public void setMetaInfo(MetaInfoType value) {
        this.metaInfo = value;
    }

    /**
     * Ruft den Wert der description-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDescription() {
        return description;
    }

    /**
     * Legt den Wert der description-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDescription(String value) {
        this.description = value;
    }

    /**
     * Ruft den Wert der variables-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link VariablesModel }
     *     
     */
    public VariablesModel getVariables() {
        return variables;
    }

    /**
     * Legt den Wert der variables-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link VariablesModel }
     *     
     */
    public void setVariables(VariablesModel value) {
        this.variables = value;
    }

    /**
     * Ruft den Wert der actions-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link TestActionsType }
     *     
     */
    public TestActionsType getActions() {
        return actions;
    }

    /**
     * Legt den Wert der actions-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link TestActionsType }
     *     
     */
    public void setActions(TestActionsType value) {
        this.actions = value;
    }

    /**
     * Ruft den Wert der finally-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link TestActionsType }
     *     
     */
    public TestActionsType getFinally() {
        return _finally;
    }

    /**
     * Legt den Wert der finally-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link TestActionsType }
     *     
     */
    public void setFinally(TestActionsType value) {
        this._finally = value;
    }

    /**
     * Ruft den Wert der name-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getName() {
        return name;
    }

    /**
     * Legt den Wert der name-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setName(String value) {
        this.name = value;
    }

}
